package core;

import java.io.Serializable;

/**
 * A class to represent a position.
 *
 * It implements equal(other), hashCode() and toString() properly.
 *
 * @author Fernando Sanchez Villaamil, Felix Reidl
 */
public class Position implements Serializable {

    public int x;
    public int y;

    public Position(int x, int y) {
	this.x = x;
	this.y = y;
    }

    public Position(Position current) {
	this(current.x, current.y);
    }

    public static Position create(int x, int y) {
	return new Position(x, y);
    }

    @Override
    public String toString() {
	return "(" + x + "," + y + ")";
    }

    @Override
    public boolean equals(Object obj) {
	if (obj == null) {
	    return false;
	}
	if (!(obj instanceof Position)) {
	    return false;
	}
	final Position other = (Position) obj;
	if (this.x != other.x) {
	    return false;
	}
	if (this.y != other.y) {
	    return false;
	}
	return true;
    }

    @Override
    public int hashCode() {
	int hash = 7;
	hash = 17 * hash + this.x;
	hash = 17 * hash + this.y;
	return hash;
    }

    /**
     *
     * @return A deep copy.
     */
    public Position copy() {
	return new Position(x, y);
    }
}
