package core;

/**
 * A simple class representing the insertion of a tile. This is the first part
 * of a move. To get instances use the static functions.
 * @author Fernando Sanchez Villaamil, Felix Reidl
 */
public class TileMove {
    public int position;
    public BoardEdge boardEdge;
    public TileType orientation;
    
    public TileMove(int position, BoardEdge direction, TileType orientation) {
        this.position = position;
        this.boardEdge = direction;
        this.orientation = orientation;
    }

    @Override
    public String toString() {
        return "TileMove{" + "position=" + position + ", boardEdge=" + boardEdge + ", orientation=" + orientation + '}';
    }
    
    public static TileMove right(int pos, TileType orientation) {
        return new TileMove(pos, BoardEdge.RIGHT, orientation);
    }
    
    public static TileMove left(int pos, TileType orientation) {
        return new TileMove(pos, BoardEdge.LEFT, orientation);
    }
    
    public static TileMove top(int pos, TileType orientation) {
        return new TileMove(pos, BoardEdge.TOP, orientation);
    }
    
    public static TileMove bottom(int pos, TileType orientation) {
        return new TileMove(pos, BoardEdge.BOTTOM, orientation);
    }
    
    public static TileMove create(int pos, BoardEdge edge, TileType orientation) {
        return new TileMove(pos, edge, orientation);
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = 89 * hash + this.position;
        hash = 89 * hash + (this.boardEdge != null ? this.boardEdge.hashCode() : 0);
        hash = 89 * hash + (this.orientation != null ? this.orientation.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final TileMove other = (TileMove) obj;
        if (this.position != other.position) {
            return false;
        }
        if (this.boardEdge != other.boardEdge) {
            return false;
        }
        if (this.orientation != other.orientation) {
            return false;
        }
        return true;
    }
}
